@@ -48,7 +48,15 @@
 -- 1 - the given name is invalid. */
 
 int glp_get_ipar(char *name, int *val)
-{     if (strcmp(name, "mps_one_entry") == 0)
+{     if (strcmp(name, "mip_branch") == 0)
+      {  /* branching technique flag */
+         *val = glp->mip_branch;
+      }
+      else if (strcmp(name, "mip_btrack") == 0)
+      {  /* backtracking technique flag */
+         *val = glp->mip_btrack;
+      }
+      else if (strcmp(name, "mps_one_entry") == 0)
       {  /* write MPS file not using fields 5 and 6 */
          *val = glp->mps_one_entry;
       }
@@ -65,22 +73,42 @@ int glp_get_ipar(char *name, int *val)
          *val = glp->mps_use_names;
       }
       else if (strcmp(name, "nc") == 0)
-      {  /* the total number of columns */
+      {  /* total number of columns */
          *val = glp->col_tab->size;
       }
+      else if (strcmp(name, "nc_bin") == 0)
+      {  /* number of binary columns */
+         GLPITEM *col;
+         int nc_bin = 0;
+         for (col = glp->first_col; col != NULL; col = col->next)
+            if (col->kind && col->type == GLP_DB &&
+                col->lb == 0.0 && col->ub == 1.0) nc_bin++;
+         *val = nc_bin;
+      }
+      else if (strcmp(name, "nc_int") == 0)
+      {  /* number of integer columns */
+         GLPITEM *col;
+         int nc_int = 0;
+         for (col = glp->first_col; col != NULL; col = col->next)
+            if (col->kind) nc_int++;
+         *val = nc_int;
+      }
       else if (strcmp(name, "nr") == 0)
-      {  /* the total number of rows */
+      {  /* total number of rows */
          *val = glp->row_tab->size;
       }
       else if (strcmp(name, "nz") == 0)
-      {  /* the total number of non-zero elements in the constraint
-            matrix */
+      {  /* total number of non-zeros in the constraint matrix */
          *val = glp->coef_pool->count;
       }
       else if (strcmp(name, "obj_dir") == 0)
       {  /* optimization direction flag */
          *val = glp->obj_dir;
       }
+      else if (strcmp(name, "option") == 0)
+      {  /* what solution should be found by the solver */
+         *val = glp->option;
+      }
       else if (strcmp(name, "round") == 0)
       {  /* round the computed values of basis variable */
          *val = glp->round;
