@@ -70,7 +70,7 @@ int glp_initialize(void)
       glp->mps_bnd_name[0] = '\0';
       glp->mps_obj_name[0] = '\0';
       glp->mps_one_entry = GLP_NO;
-      glp->mps_pedantic = GLP_NO;
+      glp->mps_pedantic = GLP_YES;
       glp->mps_rhs_name[0] = '\0';
       glp->mps_rng_name[0] = '\0';
       glp->mps_skip_empty = GLP_NO;
@@ -90,7 +90,7 @@ int glp_initialize(void)
       glp->tol_aij = 1e-15;
       glp->tol_bnd = 1e-8;
       glp->tol_dj = 1e-7;
-      glp->tol_int = 1e-7;
+      glp->tol_int = 1e-6;
       glp->tol_obj = 1e-7;
       glp->tol_piv = 1e-10;
       return 0;
