@@ -24,6 +24,7 @@
 ----------------------------------------------------------------------*/
 
 #include <errno.h>
+#include <math.h>
 #include <stdio.h>
 #include <string.h>
 #include "glpk.h"
@@ -75,9 +76,16 @@ int glp_print_sol(char *fname)
          fprintf(fp, "%-12s%d\n", "Rows:", nr);
       }
       /* number of columns (structural variables) */
-      {  int nc;
+      {  int nc, nc_int, nc_bin;
          glp_get_ipar("nc", &nc);
-         fprintf(fp, "%-12s%d\n", "Columns:", nc);
+         glp_get_ipar("nc_int", &nc_int);
+         glp_get_ipar("nc_bin", &nc_bin);
+         fprintf(fp, "%-12s%d", "Columns:", nc);
+         if (nc_int)
+            fprintf(fp, " (%d integer%s, %d binar%s)",
+               nc_int, nc_int == 1 ? "" : "s",
+               nc_bin, nc_bin == 1 ? "y" : "ies");
+         fprintf(fp, "\n");
       }
       /* number of non-zeros (constraint coefficients) */
       {  int nz;
@@ -98,7 +106,7 @@ int glp_print_sol(char *fname)
             glp_get_activity(GLP_ROW, NULL, &val, NULL);
             fprintf(fp, "%s = %.6g %s\n", name, val,
                dir == GLP_MIN  ? "(MINimization)" :
-               dir == GLP_MAX  ? "(MAXimization)" : "");
+               dir == GLP_MAX  ? "(MAXimization)" : "(???)");
          }
       }
       /* problem status */
@@ -110,41 +118,53 @@ int glp_print_sol(char *fname)
             status == GLP_FEAS   ? "FEASIBLE" :
             status == GLP_INFEAS ? "INFEASIBLE (INTERMEDIATE)" :
             status == GLP_NOFEAS ? "INFEASIBLE (FINAL)" :
-            status == GLP_UNBND  ? "UNBOUNDED" : "???");
+            status == GLP_UNBND  ? "UNBOUNDED" :
+            status == GLP_INTOPT ? "INTEGER OPTIMAL" :
+            status == GLP_INTSOL ? "INTEGER FEASIBLE" :
+            status == GLP_DISINT ? "INTEGER INFEASIBLE (INTERMEDIATE)" :
+            status == GLP_NOINT  ? "INTEGER INFEASIBLE (FINAL)" : "???")
+            ;
       }
       /* main output */
       for (kase = 0; kase <= 1; kase++)
       {  int what = kase == 0 ? GLP_ROW : GLP_COL, numb = 0, ret;
          char name[GLP_MAX_NAME+1];
          fprintf(fp, "\n");
-         fprintf(fp, "Number %-12s St   Activity     Lower bound   Uppe"
-            "r bound    Marginal\n",
-             what == GLP_ROW ? "  Row name" : "Column name");
-         fprintf(fp, "------ ------------ -- ------------- ------------"
-            "- ------------- -------------\n");
+         fprintf(fp, "  No. %-12s   St   Activity     Lower bound   Upp"
+            "er bound    Marginal\n",
+            what == GLP_ROW ? "  Row name" : "Column name");
+         fprintf(fp, "----- ------------   -- ------------- -----------"
+            "-- ------------- -------------\n");
          for (ret = glp_first_item(what); ret == 0;
               ret = glp_next_item(what))
-         {  int type, tagx;
+         {  int kind, type, tagx;
             double lb, ub, valx, dx;
             /* row/column sequential number */
             numb++;
-            fprintf(fp, "%6d ", numb);
+            fprintf(fp, "%5d ", numb);
             /* row column/name */
             glp_get_name(what, name);
             if (strlen(name) <= 12)
                fprintf(fp, "%-12s ", name);
             else
-               fprintf(fp, "%s\n%20s", name, "");
-            /* row/column ... */
+               fprintf(fp, "%s\n%19s", name, "");
+            /* get row/column information */
+            glp_get_kind(what, &kind);
             glp_get_bounds(what, &type, &lb, &ub);
             glp_get_activity(what, &tagx, &valx, &dx);
+            /* row/column kind */
+            fprintf(fp, "%s ", kind ? "*" : " ");
             /* row/column status */
             if (tagx == GLP_BS)
             {  if (type == GLP_LO && valx < lb ||
-                   type == GLP_UP && valx > ub ||
                    type == GLP_DB && valx < lb ||
-                   type == GLP_DB && valx > ub ||
-                   type == GLP_FX && valx != lb)
+                   type == GLP_FX && valx < lb)
+                  fprintf(fp, "B- ");
+               else if (type == GLP_UP && valx > ub ||
+                        type == GLP_DB && valx > ub ||
+                        type == GLP_FX && valx > ub)
+                  fprintf(fp, "B+ ");
+               else if (kind && valx != floor(valx + 0.5))
                   fprintf(fp, "B* ");
                else
                   fprintf(fp, "B  ");
