@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glpmat.h"
 #include "glpset.h"
@@ -68,7 +67,7 @@ MAT *clear_line(MAT *A, int k)
             {  ELEM *f;
                for (f = A->col[e->j]; f != NULL; f = f->col)
                   if (f->col == e) break;
-               assert(f != NULL);
+               insist(f != NULL);
                f->col = e->col;
             }
             free_atom(A->pool, e);
@@ -88,7 +87,7 @@ MAT *clear_line(MAT *A, int k)
             {  ELEM *f;
                for (f = A->row[e->i]; f != NULL; f = f->row)
                   if (f->row == e) break;
-               assert(f != NULL);
+               insist(f != NULL);
                f->row = e->row;
             }
             free_atom(A->pool, e);
