@@ -53,7 +53,7 @@
 --
 -- *Returns*
 --
--- The load_mps routine returns a pointer to an object of MPS type
+-- The load_mps routine returns a pointer to the object of MPS type
 -- that represents the loaded data in the MPS format. In case of error
 -- the routine prints an appropriate error message and returns NULL. */
 
@@ -318,7 +318,7 @@ loop: seqn++;
          if (c == '\n') break;
          if (iscntrl(c))
          {  error("%s:%d: invalid control character 0x%02X", fname,
-               seqn);
+               seqn, c);
             return 1;
          }
          if (k == 80)
