@@ -31,7 +31,7 @@
 --
 -- *Synopsis*
 --
--- #include "lp.h"
+-- #include "glpprob.h"
 -- LP *create_lp(int m, int n);
 --
 -- *Description*
