@@ -31,7 +31,7 @@
 --
 -- *Synopsis*
 --
--- #include "lp.h"
+-- #include "glpprob.h"
 -- void delete_lp(LP *lp);
 --
 -- *Description*
