@@ -40,7 +40,7 @@
 --
 -- The build_rfi routine builds RFI for the given basis matrix B (see
 -- below) in the form B = H*V. This is used when: (a) the current RFI
--- became inaccurate, (b) the current RFI requires too nuch memory, and
+-- became inaccurate, (b) the current RFI requires too much memory, and
 -- (c) the basis matrix B was completely changed.
 --
 -- The given basis matrix B should be specified implicitly by the matrix
