@@ -3,7 +3,7 @@
 /*----------------------------------------------------------------------
 -- This file is a part of the GLPK package.
 --
--- THIS CODE IS A HEADER FILE TO THE ROUTINES, WHICH ARE THE RESULT OF
+-- THIS CODE IS A HEADER FILE TO THE ROUTINES WHICH ARE THE RESULT OF
 -- TRANSLATION OF THE FORTRAN SUBROUTINES GENQMD, QMDRCH, QMDQT, QMDUPD,
 -- AND QMDMRG FROM THE BOOK:
 --
