@@ -30,17 +30,19 @@
 #include "glpset.h"
 
 /*----------------------------------------------------------------------
--- This program is a demo solver based on a *tentative* implementation
--- of the primal-dual interior point method. It is intended for solving
--- large scale linear programming problems.
+-- This program is a stand-alone LP solver based on the primal-dual
+-- interior point method.
 ----------------------------------------------------------------------*/
 
 static char *version =
-   "GLPIPM -- GLPK Interior-Point LP Solver, Version 2.2";
+   "GLPIPM -- GLPK Interior Point LP Solver, Version 2.3";
 
-static char *mps_fname = "";
-/* the name of the input text file that contains LP problem data in MPS
-   format */
+static char *dat_fname = "";
+/* name of the input text file which contains LP problem data in MPS or
+   LPM format */
+
+static int dat_fmt = 0;
+/* format of the input text file (0 means MPS, 1 means LPM) */
 
 static char *out_fname = "";
 /* the name of the output text file to which the final solution should
@@ -53,9 +55,12 @@ static char *out_fname = "";
 -- required by the GNU Coding Standards. */
 
 static void display_help(char *my_name)
-{     print("Usage: %s [options...] mps-file", my_name);
+{     print("Usage: %s [options...] data-file", my_name);
       print("");
       print("Options:");
+      print("   --mps             read LP data using MPS format (defaul"
+         "t)");
+      print("   --lpm             read LP data using LPM format");
       print("   --min             objective function should be minimize"
          "d (default)");
       print("   --max             objective function should be maximize"
@@ -105,7 +110,11 @@ static void display_version(void)
 static void process_cmdline(int argc, char *argv[])
 {     int k;
       for (k = 1; k < argc; k++)
-      {  if (strcmp(argv[k], "--min") == 0)
+      {  if (strcmp(argv[k], "--mps") == 0)
+            dat_fmt = 0;
+         else if (strcmp(argv[k], "--lpm") == 0)
+            dat_fmt = 1;
+         else if (strcmp(argv[k], "--min") == 0)
             glp_set_ipar("obj_dir", GLP_MIN);
          else if (strcmp(argv[k], "--max") == 0)
             glp_set_ipar("obj_dir", GLP_MAX);
@@ -143,11 +152,11 @@ static void process_cmdline(int argc, char *argv[])
             exit(EXIT_FAILURE);
          }
          else
-         {  if (mps_fname[0] != '\0')
+         {  if (dat_fname[0] != '\0')
             {  error("Only one input file allowed");
                exit(EXIT_FAILURE);
             }
-            mps_fname = argv[k];
+            dat_fname = argv[k];
          }
       }
       return;
@@ -166,15 +175,23 @@ int main(int argc, char *argv[])
       glp_initialize();
       /* process command line parameters */
       process_cmdline(argc, argv);
-      /* read LP problem data from MPS file */
-      if (mps_fname[0] == '\0')
-      {  error("No input MPS file specified");
+      /* read LP problem data from the input file */
+      if (dat_fname[0] == '\0')
+      {  error("No input file name specified");
          exit(EXIT_FAILURE);
       }
       glp_get_ipar("option", &option);
-      if (glp_read_mps(mps_fname) != 0)
-      {  error("Can't read MPS file");
-         exit(EXIT_FAILURE);
+      if (dat_fmt == 0)
+      {  if (glp_read_mps(dat_fname) != 0)
+         {  error("Can't read MPS file");
+            exit(EXIT_FAILURE);
+         }
+      }
+      else
+      {  if (glp_read_lpm(dat_fname) != 0)
+         {  error("Can't read LPM file");
+            exit(EXIT_FAILURE);
+         }
       }
       glp_set_ipar("option", option);
       /* solve LP problem */
